package route

import (
	"github.com/gin-gonic/gin"
	ginSwagger "github.com/swaggo/gin-swagger"
	"github.com/swaggo/gin-swagger/swaggerFiles"
	_ "hilo-group/docs"
	"hilo-group/route/group_r"
)

func InitRouter() *gin.Engine {
	var r = gin.Default()

	r.GET("/group-swagger/*any", ginSwagger.WrapHandler(swaggerFiles.Handler))

	needLogin := r.Group("")
	needLogin.Use(ExceptionHandle, LoggerHandle, JWTApiHandle)
	v1 := needLogin.Group("/v1")
	imGroup := v1.Group("/imGroup")
	{
		imGroup.GET("/popular", wrapper(group_r.GetPopularGroups))
		imGroup.GET("/latest", wrapper(group_r.GetLatestGroups))
		imGroup.GET("/recommended", wrapper(group_r.GetRecommendGroup))
		//
		imGroup.POST("/group", wrapper(group_r.CreateGroup))
		imGroup.DELETE("/group/:groupId", wrapper(group_r.DestroyGroup))
		imGroup.GET("/group/:code", wrapper(group_r.GetGroupInfo))
		imGroup.GET("/detail/:groupId", wrapper(group_r.GetGroupDetail))
		//imGroup.PUT("/group/:groupId", wrapper(ModifyGroupInfo))
		//imGroup.GET("/search/:code", wrapper(SearchGroup))
		//imGroup.DELETE("/member/:groupId", wrapper(LeaveGroup))
		//imGroup.PUT("/permanent/:groupId", wrapper(AddPermanentMember))
		//imGroup.DELETE("/permanent/:groupId", wrapper(RemovePermanentMember))
		//imGroup.GET("/permanent/:groupId", wrapper(GetPermanentMember))
		//imGroup.GET("/myRecent", wrapper(GetRecentGroup))
		//imGroup.GET("/myPermanent", wrapper(GetMyGroup))
		//
		//imGroup.GET("/visitors/:groupId", wrapper(GetGroupVisitors))
		//imGroup.GET("/ownPublicGroup/:userExternalId", wrapper(GetOwnPublicGroup))
		//// 2.19的新接口
		//imGroup.GET("/ownGroup", wrapper(GetOwnGroup))
		//imGroup.GET("/theirGroup/:userExternalId", wrapper(GetTheirGroups))
		//imGroup.PUT("/pluginReady/:groupId", wrapper(PluginReady))
		//imGroup.GET("/roomInfo/:groupId", LogRequestTime, wrapper(GetRoomInfo))
		//
		//imGroup.GET("/password/:groupId", wrapper(GetGroupPassword))
		//imGroup.GET("/role/:groupId", wrapper(GetGroupRole))
		//imGroup.PUT("/role/:groupId", wrapper(SetGroupRole))
		//imGroup.POST("/role/accept", wrapper(AcceptMemberInvite))
		//imGroup.GET("/admin/:groupId", wrapper(GetGroupAdmin))
		//
		//imGroup.PUT("/blacklist/:groupId", wrapper(AddGroupBlacklist))
		//imGroup.DELETE("/blacklist/:groupId", wrapper(RemoveGroupBlacklist))
		//imGroup.GET("/blacklist/:groupId", wrapper(GetGroupBlacklist))
		//imGroup.PUT("/kick/:groupId", wrapper(KickGroupMembers))
		//
		//imGroup.PUT("/allGroupMsg", wrapper(SendTextMsg))
		//
		//imGroup.PUT("/welcomeText/:groupId", wrapper(SetWelcomeText))
		//imGroup.GET("/support/page/:groupId", wrapper(GetSupportPage))
		//imGroup.GET("/support/detail", wrapper(GetSupportDetail))
		//imGroup.GET("/support/award/:groupId", wrapper(TryAddSupporter))
		//imGroup.POST("/support/award/:groupId", wrapper(TakeSupportAward))
		//
		//// 操作类，普通用户不用
		//imGroup.PUT("/memberLimit", wrapper(SetGroupMemberLimit))
		//imGroup.PUT("/info/reset", wrapper(ResetGroupInfo), OperationLog)
		//imGroup.PUT("/upgrade", wrapper(UpgradeGroup))
		//imGroup.PUT("/downgrade", wrapper(DowngradeGroup))
		//
		//imGroup.GET("/mic/all", wrapper(GroupMicAllInfoFive))
		//imGroup.GET("/mic/all/type", wrapper(GroupMicAllInfoTen))
		//imGroup.GET("/mic/all/type/new", wrapper(GroupMicAllInfoType))
		//imGroup.PUT("/mic/num", wrapper(GroupMicNumChange))
		//imGroup.GET("/mic/num", wrapper(GroupMicNum))
		//imGroup.POST("/mic/emoji/msg", wrapper(GroupSendMicSystemMsg))
		//imGroup.POST("/mic/in/invite/dialog", wrapper(GroupMicInInviteDialog))
		//imGroup.POST("/mic/task/invite/dialog", wrapper(GroupMicTaskInviteDialog))
		//imGroup.POST("/mic/in", LogRequestTime, wrapper(GroupMicIn))
		//imGroup.POST("/mic/invite", LogRequestTime, wrapper(GroupMicInvite))
		//imGroup.POST("/mic/leave", LogRequestTime, wrapper(GroupMicLeave))
		//imGroup.POST("/mic/lock", wrapper(GroupMicLock))
		//imGroup.POST("/mic/unlock", wrapper(GroupMicUnLock))
		//imGroup.POST("/mic/speech/open", wrapper(GroupMicSpeechOpen))
		//imGroup.POST("/mic/speech/close", wrapper(GroupMicSpeechClose))
		//imGroup.POST("/mic/mute", wrapper(GroupMicMute))
		//imGroup.POST("/mic/unmute", wrapper(GroupMicUnmute))
		//imGroup.PUT("/in", LogRequestTime, wrapper(GroupIn))
		//imGroup.POST("/leave", wrapper(GroupLeave))
		//imGroup.POST("/kick", wrapper(GroupKick))
		//imGroup.PUT("/user/msg/status", wrapper(GroupUserMsg))
		//imGroup.POST("/report", wrapper(GroupReport))
		//imGroup.GET("/banner/list", wrapper(GroupBannerList))
		//imGroup.GET("/roomBanners", wrapper(RoomBannerList))
		//imGroup.PUT("/roomBanners", wrapper(NotifyRoomBannerListChange))
		//imGroup.POST("/mic/gift", wrapper(GroupMicGift))
		//imGroup.POST("/mic/mass", wrapper(GroupMicMass))
		//imGroup.POST("/mgr/mass", wrapper(GroupMgrMass))
		//imGroup.POST("/mgr/clearScreen", wrapper(GroupMgrClearScreen))
		//imGroup.GET("/online/users", wrapper(GroupInUsers))
		//imGroup.GET("/online/users/new", wrapper(GroupInUserNew))
		//imGroup.GET("/country", wrapper(GetGroupByCountry))
		//imGroup.GET("/country/prior", wrapper(GroupountryPrior))
		//
		//imGroup.POST("/theme/custom", wrapper(GroupThemeAdd))
		//imGroup.GET("/theme/custom/config", wrapper(GroupThemeConfig))
		//imGroup.PUT("/theme/custom/using", wrapper(GroupThemeUsing))
		//imGroup.GET("/theme/custom/all", wrapper(GroupThemeValidAll))
		//
		//imGroup.GET("/medal/all", wrapper(GroupMedalAll))
		//imGroup.GET("/medal/room", wrapper(GetRoomMedal))
	}
	return r
}
